@@ -48,7 +48,7 @@ nMDS <- setClass(
         chckpkg("vegan")
 
         meta <- data@meta
-        orgdata <- if (keep.org.data) data@data else NULL
+        orgdata <- if (keep.org.data) data@data else matrix(0, 0, 0)
         indata <- data@data
 
         outdata <- vegan::monoMDS(pars$d(indata), k = pars$ndim)$points
