@@ -35,16 +35,11 @@
 #'
 #' @examples
 #' dat <- loadDataSet("Iris")
-#'
-#' ## using the S4 Class
-#' pca <- PCA()
-#' emb <- pca@fun(dat, pca@stdpars)
-#'
-#' ## using embed()
-#' emb2 <- embed(dat, "PCA")
+#' emb <- embed(dat, "PCA")
 #'
 #' plot(emb, type = "2vars")
-#' plot(emb@inverse(emb@data), type = "3vars")
+#' if(requireNamespace("scatterplot3d", quietly = TRUE))
+#'   plot(inverse(emb, getDimRedData(emb)), type = "3vars")
 #'
 #' @include dimRedResult-class.R
 #' @include dimRedMethod-class.R
@@ -64,7 +59,7 @@ PCA <- setClass(
         pars$ndim <- NULL
 
         meta <- data@meta
-        orgdata <- if (keep.org.data) data@data else NULL
+        orgdata <- if (keep.org.data) data@data else matrix(0, 0, 0)
         data <- data@data
         res <- do.call(
             prcomp,
